(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

exception Uwobo_failure of string

  (** XML namespace of UWOBO generated XML elements *)
val uwobo_namespace: string

val supported_properties: string list
val is_supported_property: string -> bool

val version: string (** version *)
val usage_string: string  (** HTTP GET usage string *)

  (** return an ok (200) http response, which display in html an error message.
  Error title is reported inside an h1 tag; error body, if given, follows *)
val return_error: string -> ?body: string -> out_channel -> unit
  (** return a 400 (bad request) http response *)
val bad_request: string -> out_channel -> unit

  (** {2 LibXSLT logging} *)

  (** libxslt's message *)
type xslt_msg =
  | LibXsltErrorMsg of string   (** libxslt's error messages *)
  | LibXsltDebugMsg of string   (** libxslt's debugging messages *)

  (** pretty print a xslt_msg *)
val string_of_xslt_msg: xslt_msg -> string

  (** libxslt's message reporting mode. That is: how to report libxslt's
  messages during apply method *)
type xslt_msg_mode =
  | LibXsltMsgIgnore    (** Ignore some kind of messages *)
  | LibXsltMsgComment   (** Embed in XML comments some kind of messages *)
  | LibXsltMsgEmbed     (** Embed in XML elements some kind of messages *)

class libXsltLogger:
  object

    method clearMsgs: unit
    method clearErrorMsgs: unit
    method clearDebugMsgs: unit

    method msgs: xslt_msg list
    method errorMsgs: string list
    method debugMsgs: string list

  end

