(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

type priority = [
  | `Emerg    (* system is unusable *)
  | `Alert    (* action must be taken immediately *)
  | `Crit     (* critical conditions *)
  | `Err      (* error conditions *)
  | `Warning  (* warning conditions *)
  | `Notice   (* normal, but significant, condition *)
  | `Info     (* informational message *)
  | `Debug    (* debug-level message *)
]

  (**
  Warning: logging is disabled by default, you have to invoke #enable method
  before being able to log anything.
  @param level minimum level of priority that will be reported, msg with
  priority less than this will be ignored
  @param outchan output channel on which output log messages *)
class sysLogger:
  ?level: priority -> ?outchan: out_channel ->
  unit ->
    object
      method level: priority
      method levelNo: int
        (** enable logging, by default logging is disabled *)
      method enable: unit
        (** disable logging *)
      method disable: unit
        (** log a message *)
      method log: priority -> string -> unit
    end

class processingLogger:
  unit ->
    object
      method log: string -> unit
      method logBold: string -> unit
      method logEmph: string -> unit
      method asText: string
      method asHtml: string
    end

